@@ -10,27 +10,27 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
+$VERSION = '0.03';
 $DATE = '2004/05/10';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_Maker.pm' => [qw(0.02 2004/05/10), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2004/05/10), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2004/05/10), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2004/05/10), 'generated, replaces 0.01'],
-    'lib/File/Maker.pm' => [qw(0.02 2004/05/10), 'revised 0.01'],
-    't/File/Maker.d' => [qw(0.01 2004/05/10), 'unchanged'],
-    't/File/Maker.pm' => [qw(0.02 2004/05/10), 'revised 0.01'],
-    't/File/Maker.t' => [qw(0.02 2004/05/10), 'revised 0.01'],
+    'lib/Docs/Site_SVD/File_Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
+    'lib/File/Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
+    't/File/Maker.d' => [qw(0.02 2004/05/10), 'revised 0.01'],
+    't/File/Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
+    't/File/Maker.t' => [qw(0.03 2004/05/10), 'revised 0.02'],
     't/File/_Maker_/MakerDB.pm' => [qw(0.01 2004/05/10), 'unchanged'],
     't/File/File/Package.pm' => [qw(1.16 2004/05/10), 'unchanged'],
     't/File/File/SmartNL.pm' => [qw(1.14 2004/05/10), 'unchanged'],
-    't/File/Test/Tech.pm' => [qw(1.22 2004/05/10), 'unchanged'],
-    't/File/Data/Secs2.pm' => [qw(1.2 2004/05/10), 'unchanged'],
-    't/File/Data/SecsPack.pm' => [qw(0.05 2004/05/10), 'unchanged'],
-    't/File/Data/Startup.pm' => [qw(0.04 2004/05/10), 'unchanged'],
+    't/File/Test/Tech.pm' => [qw(1.23 2004/05/10), 'revised 1.22'],
+    't/File/Data/Secs2.pm' => [qw(1.21 2004/05/10), 'revised 1.2'],
+    't/File/Data/SecsPack.pm' => [qw(0.06 2004/05/10), 'revised 0.05'],
+    't/File/Data/Startup.pm' => [qw(0.05 2004/05/10), 'revised 0.04'],
 
 );
 
@@ -59,7 +59,7 @@ use vars qw(%INVENTORY);
 
  Revision: -
 
- Version: 0.02
+ Version: 0.03
 
  Date: 2004/05/10
 
@@ -109,7 +109,7 @@ and macros in a "makefile".
 
 =head2 1.3 Document overview.
 
-This document releases File::Maker version 0.02
+This document releases File::Maker version 0.03
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -124,7 +124,7 @@ system file specification.
 
 This document releases the file 
 
- File-Maker-0.02.tar.gz
+ File-Maker-0.03.tar.gz
 
 found at the following repository(s):
 
@@ -196,21 +196,21 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_Maker.pm                              0.02    2004/05/10 revised 0.01
- MANIFEST                                                     0.02    2004/05/10 generated, replaces 0.01
- Makefile.PL                                                  0.02    2004/05/10 generated, replaces 0.01
- README                                                       0.02    2004/05/10 generated, replaces 0.01
- lib/File/Maker.pm                                            0.02    2004/05/10 revised 0.01
- t/File/Maker.d                                               0.01    2004/05/10 unchanged
- t/File/Maker.pm                                              0.02    2004/05/10 revised 0.01
- t/File/Maker.t                                               0.02    2004/05/10 revised 0.01
+ lib/Docs/Site_SVD/File_Maker.pm                              0.03    2004/05/10 revised 0.02
+ MANIFEST                                                     0.03    2004/05/10 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2004/05/10 generated, replaces 0.02
+ README                                                       0.03    2004/05/10 generated, replaces 0.02
+ lib/File/Maker.pm                                            0.03    2004/05/10 revised 0.02
+ t/File/Maker.d                                               0.02    2004/05/10 revised 0.01
+ t/File/Maker.pm                                              0.03    2004/05/10 revised 0.02
+ t/File/Maker.t                                               0.03    2004/05/10 revised 0.02
  t/File/_Maker_/MakerDB.pm                                    0.01    2004/05/10 unchanged
  t/File/File/Package.pm                                       1.16    2004/05/10 unchanged
  t/File/File/SmartNL.pm                                       1.14    2004/05/10 unchanged
- t/File/Test/Tech.pm                                          1.22    2004/05/10 unchanged
- t/File/Data/Secs2.pm                                         1.2     2004/05/10 unchanged
- t/File/Data/SecsPack.pm                                      0.05    2004/05/10 unchanged
- t/File/Data/Startup.pm                                       0.04    2004/05/10 unchanged
+ t/File/Test/Tech.pm                                          1.23    2004/05/10 revised 1.22
+ t/File/Data/Secs2.pm                                         1.21    2004/05/10 revised 1.2
+ t/File/Data/SecsPack.pm                                      0.06    2004/05/10 revised 0.05
+ t/File/Data/Startup.pm                                       0.05    2004/05/10 revised 0.04
 
 
 =head2 3.3 Changes
@@ -219,16 +219,21 @@ Changes are as follows:
 
 =over 4
 
-=item File::Maker 0.01
+=item File-Maker-0.01
 
 Originated
 
-=item File::Maker 0.02
+=item File-Maker-0.02
 
 Need a return at top of the C<__DATA__> record to be 
 compatible with obsolete C<DataPort::Maker> program
 module.
 
+=item File-Maker-0.03
+
+Restore C<@INC> in C<load_db> subroutine.
+Added test for the same.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -267,13 +272,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'File-Maker-0.02.tar.gz' and download to a temporary
+Right click on 'File-Maker-0.03.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip File-Maker-0.02.tar.gz
- tar -xf File-Maker-0.02.tar
+ gunzip File-Maker-0.03.tar.gz
+ tar -xf File-Maker-0.03.tar
  perl Makefile.PL
  $make test
  $make install
@@ -358,23 +363,14 @@ United States
 
 =head1 2.0 SEE ALSO
 
-L<File::Maker|File::Maker>
+=over 4
+
+=item L<File::Maker|File::Maker>
+
+=back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -388,10 +384,10 @@ DISTNAME:
 File-Maker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.02^
+VERSION : 0.03^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
+PREVIOUS_RELEASE: 0.02^
 REVISION: -^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -447,16 +443,21 @@ Changes are as follows:
 
 \=over 4
 
-\=item File::Maker 0.01
+\=item File-Maker-0.01
 
 Originated
 
-\=item File::Maker 0.02
+\=item File-Maker-0.02
 
 Need a return at top of the C<__DATA__> record to be 
 compatible with obsolete C<DataPort::Maker> program
 module.
 
+\=item File-Maker-0.03
+
+Restore C<@INC> in C<load_db> subroutine.
+Added test for the same.
+
 \=back
 
 ^
@@ -623,27 +624,16 @@ United States
 
 SEE_ALSO:
 
- L<File::Maker|File::Maker>
+\=over 4
 
+\=item L<File::Maker|File::Maker>
 
+\=back
 
 ^
 
 HTML:
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 ^
 ~-~
 
@@ -660,3 +650,7 @@ HTML:
 
 
 
+
+
+
+
